import {NativeEventEmitter, NativeModules, Platform} from 'react-native';

const _RNAudioDevice = NativeModules.RNAudioDevice;
const DeviceInfoEventEmitter = new NativeEventEmitter(_RNAudioDevice);
const _subscriptions = new Map();

class RNAudioDevice {
  constructor() {}

  addEventListener(eventName, handler) {
    const listener = DeviceInfoEventEmitter.addListener(
          eventName,
          (appStateData) => {
            handler({
              data: appStateData,
            });
          },
        );

    _subscriptions.set(handler, listener);
    return {
      remove: () => RNAudioDevice.removeEventListener(eventName, handler),
    };
  }

  /**
   * Removes the listener for network status changes.
   */
  removeEventListener(eventName, handler) {
    const listener = _subscriptions.get(handler);
    if (!listener) {
      return;
    }
    listener.remove();
    _subscriptions.delete(handler);
  }

  // Stop device management thread
  stop() {
    _RNAudioDevice.stop();
  }

  // StartRecognize for audio.
  startRecognize() {
    _RNAudioDevice.startRecognize();
  }

  // StopRecognize for audio.
  stopRecognize() {
    _RNAudioDevice.stopRecognize();
  }

  // Enable/Disable spearker phone
  setSpeakerphoneOn(enable) {
    enable = enable === true ? true : false;
    _RNAudioDevice.setSpeakerphoneOn(enable);
  }

  setForceSpeakerphoneOn(_flag) {
    let flag = typeof _flag === 'boolean' ? (_flag ? 1 : -1) : 0;
    _RNAudioDevice.setForceSpeakerphoneOn(flag);
  }

  setMicrophoneMute(enable) {
    enable = enable === true ? true : false;
    _RNAudioDevice.setMicrophoneMute(enable);
  }

  // Choose any audio output device(SPEAKER_PHONE,WIRED_HEADSET,EARPIECE,BLUETOOTH)
  async chooseAudioRoute(route) {
    let result = await _RNAudioDevice.chooseAudioRoute(route);
    return result;
  }
}

export default new RNAudioDevice();
